Package: pvar
Version: 2.2.7
Title: Calculation and Application of p-Variation
Date: 2022-10-18
Author: Vygantas Butkus
Maintainer: Vygantas Butkus <Vygantas.Butkus@gmail.com>
Description: The calculation of p-variation of the finite sample data. 
	This package is a realisation of the procedure described in Butkus, V. & Norvaisa, R. Lith Math J (2018). <doi: 10.1007/s10986-018-9414-3>
	The formal definitions and reference into literature are given in vignette.
LazyData: yes
Imports: Rcpp (>= 0.11.1)
LinkingTo: Rcpp
Suggests: e1071, testthat, knitr, formatR,
VignetteBuilder: knitr
License: GPL-2
RoxygenNote: 6.1.1
NeedsCompilation: yes
Packaged: 2022-10-18 04:28:51 UTC; vygantas
Repository: CRAN
Date/Publication: 2022-10-18 07:40:06 UTC
Built: R 4.2.0; aarch64-apple-darwin20; 2023-04-01 14:57:29 UTC; unix
Archs: pvar.so.dSYM
