# Generated by roxygen2: do not edit by hand

S3method(Ops,pvar)
S3method(as.list,pvar)
S3method(plot,PvarBreakTest)
S3method(plot,pvar)
S3method(print,PvarBreakTest)
S3method(print,pvar)
S3method(print,summary.PvarBreakTest)
S3method(print,summary.pvar)
S3method(summary,PvarBreakTest)
S3method(summary,pvar)
export("%.%")
export(AddPvar)
export(AddPvarC)
export(BridgeT)
export(ChangePoints)
export(IsEqualPvar)
export(NormalisePvar)
export(PvarBreakTest)
export(PvarPvalue)
export(PvarQuantile)
export(Sum_p)
export(getMean)
export(getSd)
export(pvar)
export(pvarC)
export(rbridge)
export(rcumbin)
export(rwiener)
import(Rcpp)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(stats,filter)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,time)
importFrom(stats,ts)
importFrom(stats,var)
useDynLib(pvar)
