R package `pvar`
==================================

This package deals with the $p$-variation of the sample. Nonetheless,
it could be used for to calculate $p$-variation for arbitrary
piecewise monotonic function as well. See:

https://link.springer.com/article/10.1007/s10986-018-9414-3#citeas

If you intend to have use from this package, you need to be familiar with the topic.
The formal definitions and reference into literature are given in vignette.

There are two main functions in this package, namely

* pvar - it is a function that calculates the $p$-variation of the sample.
* PvarBreakTest - it is functions that performs a test of multiple changes in a sequence of independent observations. This
is one of the example of $p$-variation use in statistics.

In any question or remarks please don't hesitate to contact me by Vygantas.Butkus@gmail.com


Best regards,

Vygantas Butkus
